import geompy
import math
import SALOMEDS


# =====================================================
def PrintMeshInfo(theMesh):
    aMesh = theMesh.GetMesh()
    print "Information about mesh:"
    print "Number of nodes:   ", aMesh.NbNodes()
    print "Number of edges:   ", aMesh.NbEdges()
    print "Number of faces:   ", aMesh.NbFaces()
    print "Number of volumes: ", aMesh.NbVolumes()
    pass
# =====================================================

Mfineness = 0.15
thickness = 0.02

# define points
p00 = geompy.MakeVertex(0, 0, 0)
p10 = geompy.MakeVertex(1, 0, 0)
p11 = geompy.MakeVertex(1, 1, 0)
p01 = geompy.MakeVertex(0, 1, 0)
pz1 = geompy.MakeVertex(0, 0, 1)

# define vector
vz1 = geompy.MakeVector(p00, pz1)


# define lines between two points
lf1 = geompy.MakeLineTwoPnt(p00, p10)
lf2 = geompy.MakeLineTwoPnt(p10, p11)
lf3 = geompy.MakeLineTwoPnt(p11, p01)
lf4 = geompy.MakeLineTwoPnt(p01, p00)

# define face from 4 wires
Face1 = geompy.MakeFaceWires([lf1, lf2, lf3, lf4], 1)
listSubShapeIDs = geompy.SubShapeAllIDs(Face1, geompy.ShapeType["FACE"])

# define extrusion - base is Face1 in direction of vector vz1 and thickness 0.01
th = thickness
Extrusion1 = geompy.MakePrismVecH(Face1,vz1,th)

listSubShapeIDs = geompy.SubShapeAllIDs(Extrusion1, geompy.ShapeType["EDGE"])
lf1 = geompy.CreateGroup(Extrusion1, geompy.ShapeType["EDGE"])
geompy.UnionIDs(lf1, [25])  #18
Extrusion1 = geompy.GetMainShape(lf1)

lf2 = geompy.CreateGroup(Extrusion1, geompy.ShapeType["EDGE"])
geompy.UnionIDs(lf2, [29])  #11
Extrusion1 = geompy.GetMainShape(lf2)

lf3 = geompy.CreateGroup(Extrusion1, geompy.ShapeType["EDGE"])
geompy.UnionIDs(lf3, [11])  #25
Extrusion1 = geompy.GetMainShape(lf3)

lf4 = geompy.CreateGroup(Extrusion1, geompy.ShapeType["EDGE"])
geompy.UnionIDs(lf4, [18])  #29
Extrusion1 = geompy.GetMainShape(lf4)

zaxis = geompy.CreateGroup(Extrusion1, geompy.ShapeType["EDGE"])
geompy.UnionIDs(zaxis, [15])
Extrusion1 = geompy.GetMainShape(zaxis)



# define surfbot
surfbot = geompy.CreateGroup(Extrusion1, geompy.ShapeType["FACE"])
geompy.UnionIDs(surfbot, [31])
Extrusion1 = geompy.GetMainShape(surfbot)

pf1 = geompy.CreateGroup(Extrusion1, geompy.ShapeType["FACE"])
geompy.UnionIDs(pf1, [20])
Extrusion1 = geompy.GetMainShape(pf1)

pf2 = geompy.CreateGroup(Extrusion1, geompy.ShapeType["FACE"])
geompy.UnionIDs(pf2, [27])
Extrusion1 = geompy.GetMainShape(pf2)

pf3 = geompy.CreateGroup(Extrusion1, geompy.ShapeType["FACE"])
geompy.UnionIDs(pf3, [3])
Extrusion1 = geompy.GetMainShape(pf3)

pf4 = geompy.CreateGroup(Extrusion1, geompy.ShapeType["FACE"])
geompy.UnionIDs(pf4, [13])
Extrusion1 = geompy.GetMainShape(pf4)

# add all parts to the study
geompy.addToStudy( p00, "p00" )
geompy.addToStudy( p10, "p10" )
geompy.addToStudy( p11, "p11" )
geompy.addToStudy( p01, "p01" )

geompy.addToStudy( pz1, "pz1" )  # vector
geompy.addToStudy( vz1, "vz1" )  

geompy.addToStudy( lf1, "lf1" )  # lines
geompy.addToStudy( lf2, "lf2" )
geompy.addToStudy( lf3, "lf3" )
geompy.addToStudy( lf4, "lf4" )

geompy.addToStudy( Face1, "Face1" )   # face
geompy.addToStudy( Extrusion1, "Extrusion1" )
geompy.addToStudyInFather( Extrusion1, lf1, "lf1" )
geompy.addToStudyInFather( Extrusion1, lf2, "lf2" )
geompy.addToStudyInFather( Extrusion1, lf3, "lf3" )
geompy.addToStudyInFather( Extrusion1, lf4, "lf4" )
geompy.addToStudyInFather( Extrusion1, surfbot, "surfbot" )
geompy.addToStudyInFather( Extrusion1, pf1, "pf1" )
geompy.addToStudyInFather( Extrusion1, pf2, "pf2" )
geompy.addToStudyInFather( Extrusion1, pf3, "pf3" )
geompy.addToStudyInFather( Extrusion1, pf4, "pf4" )
geompy.addToStudyInFather( Extrusion1, zaxis, "zaxis" )

#==================================================================
import salome, SMESH
import smesh
import StdMeshers

fineness1 = Mfineness

pattern = smesh.GetPattern()
quad2t = smesh.Mesh(Extrusion1)
Regular_1D = quad2t.Segment()
Automatic_length = Regular_1D.AutomaticLength(fineness1)
Quadratic_quad2t = Regular_1D.QuadraticMesh()
Quadrangle_2D = quad2t.Quadrangle()
Quadrangle_Preference = Quadrangle_2D.QuadranglePreference()
Hexa_3D = quad2t.Hexahedron()

Automatic_length.SetFineness( fineness1 )

isDone = quad2t.Compute()

## set object names  
smesh.SetName(quad2t.GetMesh(), 'quad2t')
smesh.SetName(Regular_1D.GetAlgorithm(), 'Regular_1D')
smesh.SetName(Automatic_length, 'Automatic length')
smesh.SetName(Quadratic_quad2t, 'Quadratic Mesh')
smesh.SetName(Quadrangle_2D.GetAlgorithm(), 'Quadrangle_2D')
smesh.SetName(Quadrangle_Preference, 'Quadrangle Preference')
smesh.SetName(Hexa_3D.GetAlgorithm(), 'Hexa_3D')


Liney0 = quad2t.Group(lf1)
Linex0 = quad2t.Group(lf2)
Liney1 = quad2t.Group(lf3)
Linex1 = quad2t.Group(lf4)
Zaxis  = quad2t.Group(zaxis)
Surfbot = quad2t.Group(surfbot)
PF1 = quad2t.Group(pf1)
PF2 = quad2t.Group(pf2)
PF3 = quad2t.Group(pf3)
PF4 = quad2t.Group(pf4)

smesh.SetName(quad2t.GetMesh(), 'quad2t')
smesh.SetName(lf1, 'lf1')
smesh.SetName(lf2, 'lf2')
smesh.SetName(lf3, 'lf3')
smesh.SetName(lf4, 'lf4')
smesh.SetName(zaxis, 'zaxis')
smesh.SetName(pf1, 'pf1')
smesh.SetName(pf2, 'pf2')
smesh.SetName(pf3, 'pf3')
smesh.SetName(pf4, 'pf4')

salome.sg.updateObjBrowser(0)

PrintMeshInfo(quad2t)
#====================

quad2t.ExportMED( '/home/kees/solidplate/quad2t.med',0)
#quad2t.ExportMED('<<path>>/quad2tq.med',0)



